CircleFloatingButton class

Inheritance

Constructors

CircleFloatingButton({Key? key, required List<Widget> items, double radius = 100, Position position = Position.right, double? right, double? top, bool completeCircle = false, Duration duration = const Duration(milliseconds: 300), required CircleType type, required Color buttonColor, required IconData buttonIcon, required Curve curve, required bool opacity, Widget? child})
CircleFloatingButton.completeCircle({required List<Widget> items, double radius = 100, required Duration duration, required IconData icon, required Color color, required Curve curveAnim, required bool useOpacity, Key? key, required Widget child})
factory
CircleFloatingButton.floatingActionButton({required List<Widget> items, double radius = 100, required Duration duration, required IconData icon, required Color color, required Curve curveAnim, required bool useOpacity, Key? key, Widget? child})
factory
CircleFloatingButton.semiCircle({required List<Widget> items, Key? key, double radius = 100, required Position position, required Duration duration, required IconData icon, required Color color, required Curve curveAnim, required bool useOpacity, Widget? child})
factory

Properties

buttonColor → Color
final
buttonIcon → IconData
final
child → Widget?
final
completeCircle → bool
final
curve → Curve
final
duration → Duration
final
hashCode → int
The hash code for this object.
no setterinherited
items → List<Widget>
final
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
opacity → bool
final
position → Position
final
radius → double
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double?
final
type → CircleType
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → CircleFloatingButtonState
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited